==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_tw() {
            return 1;
        }
        get_up() {
            return new ForceIndexIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return ForceIndexIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get va() {
            return typeGetValue(this.c(ForceIndexIndicator.vb));
        }
        set va(a) {
            this.h(ForceIndexIndicator.vb, a);
        }
        uv() {
            return this.va;
        }
        u4(a) {
            this.va = a;
        }
    }
    ForceIndexIndicator.$t = markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.vb = StrategyBasedIndicator.u7(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_x5() {
            return 1;
        }
        get_yy() {
            return new ForceIndexIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return ForceIndexIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(ForceIndexIndicator.zk));
        }
        set zj(a) {
            this.h(ForceIndexIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    ForceIndexIndicator.$t = markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.zk = StrategyBasedIndicator.zg(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();
